@@ -2,8 +2,10 @@ from snatch.banco_central import BancoCentral  # noqa
 from snatch.boa_vista import BoaVista  # noqa
 from snatch.cgu_pep import PEP  # noqa
 from snatch.data_risk import DataRisk  # noqa
+from snatch.fgts import FGTS  # noqa
+from snatch.ibama import Ibama  # noqa
 from snatch.protestos import Protest  # noqa
 from snatch.qsa import QSA  # noqa
 from snatch.receita_federal_pj import ReceitaFederalPJ  # noqa
 
-__version__ = "2.9.0"
+__version__ = "2.11.0"
