@@ -69,7 +69,9 @@ class BaseData:
         :param max_periods_old: Max months old for current data, for check expiration.
         """
         if self.integration_status == "SUCCESS":
-            days_old = (arrow.utcnow() - arrow.get(self.prospect_date)).days
+            days_old = (
+                arrow.utcnow().ceil("day") - arrow.get(self.prospect_date).floor("day")
+            ).days
             months_old = days_old / 30
             expired_by_date = max_days_old is not None and days_old > max_days_old
             expired_by_period = (
